# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding unique constraint on 'Subscriber', fields ['email']
        db.create_unique('registration_subscriber', ['email'])


    def backwards(self, orm):
        
        # Removing unique constraint on 'Subscriber', fields ['email']
        db.delete_unique('registration_subscriber', ['email'])


    models = {
        'registration.subscriber': {
            'Meta': {'object_name': 'Subscriber'},
            'email': ('django.db.models.fields.EmailField', [], {'unique': 'True', 'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'subscription_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['registration']



from django.db import models


class Subscriber(models.Model):
    name = models.CharField(max_length=255)
    email = models.EmailField(max_length=255, unique=True)
    subscription_date = models.DateTimeField(auto_now_add=True)

    def __unicode__(self):
        return self.name



# -*- coding: utf-8 -*-
from django import http
from django.template import response
from django.views.generic import base

from mittun.registration import forms


class SubscribeView(base.View):

    def __init__(self, *args, **kwargs):
        super(SubscribeView, self).__init__(*args, **kwargs)
        if not hasattr(self, "success_url"):
            self.success_url = "/successful-subscribed/"

    def get(self, request):
        template_name = getattr(self, "template_name", "subscribe.html")
        context = {"form": forms.SubscriberForm()}
        return response.TemplateResponse(request, template_name, context)

    def post(self, request):
        form = forms.SubscriberForm(request.POST)
        if form.is_valid():
            form.save()
            return http.HttpResponseRedirect(self.success_url)

        template_name = getattr(self, "template_name", "subscribe.html")
        context = {"form": form}
        return response.TemplateResponse(request, template_name, context)



#-*- coding:utf-8 -*-
from os.path import dirname
from optparse import make_option
from django.core.management.base import BaseCommand
from django.conf import settings
from events.management.browser_helper import browser

import nose
import time


class Command(BaseCommand):

    browser = None
    help = "Run acceptance tests"

    option_list = BaseCommand.option_list + (
        make_option("-a", "--app", dest="app", default=None),
    )

    def handle(self, *args, **options):

        # if not options['sem_db_migrate']:
        #     print 'cleaning temp data...'
        #     self.clean()
        #     print 'reseting database...'
        #     self.reset_db()

        app = options["app"]

        if app:
            apps = [app]
        else:
            apps = settings.TESTABLE_APPS

        self.run(apps)

    def clean(self):
        self.run_target(self.clean_target)

    def run_target(self, target):
        target.execute()
        while not target.poll():
            time.sleep(0.5)

    def reset_db(self):
        self.run_target(self.db)

    def run(self, apps):
        nose_argv = ['nosetests','-sd', '--verbosity=2', '--nologcapture']

        test_file = False
        test_type = 'acceptance'

        modules = []
        if not test_file:
            for app in apps:
                test_module_path = "%s.tests" % (app)
                try:
                    module = getattr(__import__(test_module_path, locals(), globals(), [test_type], 3), test_type)
                    modules.append(module)
                except AttributeError:
                    pass
            nose_argv.extend([dirname(x.__file__) for x in modules])

        else:
            nose_argv.append(test_file)
        ret = nose.run(argv=nose_argv)

        browser.quit()

        if ret:
            code = 0
        else:
            code = 1



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding field 'Event.url'
        db.add_column('events_event', 'url', self.gf('django.db.models.fields.CharField')(default=None, max_length=250), keep_default=False)


    def backwards(self, orm):
        
        # Deleting field 'Event.url'
        db.delete_column('events_event', 'url')


    models = {
        'events.event': {
            'Meta': {'object_name': 'Event'},
            'address': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'date': ('django.db.models.fields.DateField', [], {}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'location': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        }
    }

    complete_apps = ['events']



from django.contrib import admin

from mittun.events.models import Location, Event


class EventAdmin(admin.ModelAdmin):
    pass


class LocationAdmin(admin.ModelAdmin):
    pass


admin.site.register(Location, LocationAdmin)
admin.site.register(Event, EventAdmin)



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Deleting field 'Event.description'
        db.delete_column('events_event', 'description')

        # Adding field 'Event.description_en_us'
        db.add_column('events_event', 'description_en_us', self.gf('django.db.models.fields.CharField')(default='', max_length=200), keep_default=False)

        # Adding field 'Event.description_pt_br'
        db.add_column('events_event', 'description_pt_br', self.gf('django.db.models.fields.CharField')(max_length=200, null=True, blank=True), keep_default=False)


    def backwards(self, orm):
        
        # Adding field 'Event.description'
        db.add_column('events_event', 'description', self.gf('django.db.models.fields.CharField')(default='', max_length=200), keep_default=False)

        # Deleting field 'Event.description_en_us'
        db.delete_column('events_event', 'description_en_us')

        # Deleting field 'Event.description_pt_br'
        db.delete_column('events_event', 'description_pt_br')


    models = {
        'events.event': {
            'Meta': {'object_name': 'Event'},
            'date': ('django.db.models.fields.DateField', [], {}),
            'description_en_us': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'description_pt_br': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'logo': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '50', 'db_index': 'True'})
        },
        'events.location': {
            'Meta': {'object_name': 'Location'},
            'address': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['events.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '150'})
        }
    }

    complete_apps = ['events']



from django.contrib import admin

from mittun.sponsors.models import Sponsor, Category, Contact


class ContactInline(admin.TabularInline):
    model = Contact


class ContactAdmin(admin.ModelAdmin):
    pass


class SponsorAdmin(admin.ModelAdmin):

    inlines = [
        ContactInline,
    ]


class CategoryAdmin(admin.ModelAdmin):
    pass


if Contact not in admin.site._registry:
    admin.site.register(Contact, ContactAdmin)
if Sponsor not in admin.site._registry:
    admin.site.register(Sponsor, SponsorAdmin)
if Category not in admin.site._registry:
    admin.site.register(Category, CategoryAdmin)



from django.conf.urls.defaults import patterns, include, url
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.contrib import admin

from mittun.views import IndexView, AboutView

admin.autodiscover()


urlpatterns = patterns('',
    url(r'^$', IndexView.as_view()),
    url(r'^index/?$', IndexView.as_view(), name="index"),
    url(r'^about/?$', AboutView.as_view(), name="about"),
    url(r'^admin/', include(admin.site.urls)),
    url(r'^sponsors/?$', include('mittun.sponsors.urls')),
)

urlpatterns += staticfiles_urlpatterns()



from setuptools import setup, find_packages
from mittun import __version__

README = open('README.rst').read()

setup(name="mittun",
      version=__version__,
      description="conference manager",
      long_description=README,
      author="Flavia Missi",
      author_email="flaviamissi@gmail.com",
      packages=find_packages(exclude=['docs', '*.tests', '*.tests.*', 'tests.*']),
      include_package_data=True,
      install_requires=["MySQL-Python==1.2.3", "django==1.3.1", "South==0.7.3", "PIL==1.1.7"],
      tests_require=["nose==1.0.0", "django_nose==0.1.3", "coverage==3.4", "specloud==0.4.2", "splinter", "PyYAML"]
)



from django.db import models
from transmeta import TransMeta


class Location(models.Model):

    title = models.CharField(max_length=150)
    event = models.ForeignKey("Event")
    address = models.CharField(max_length=255)


class Event(models.Model):
    __metaclass__ = TransMeta

    name = models.CharField(max_length=100)
    description = models.TextField(max_length=200)

    class Meta:
        translate = ('description',)

    def __unicode__(self):
        return self.name



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Changing field 'Sponsor.description_pt_br'
        db.alter_column('sponsors_sponsor', 'description_pt_br', self.gf('django.db.models.fields.TextField')(max_length=255, null=True))

        # Changing field 'Sponsor.description_en_us'
        db.alter_column('sponsors_sponsor', 'description_en_us', self.gf('django.db.models.fields.TextField')(max_length=255))


    def backwards(self, orm):
        
        # Changing field 'Sponsor.description_pt_br'
        db.alter_column('sponsors_sponsor', 'description_pt_br', self.gf('django.db.models.fields.CharField')(max_length=255, null=True))

        # Changing field 'Sponsor.description_en_us'
        db.alter_column('sponsors_sponsor', 'description_en_us', self.gf('django.db.models.fields.CharField')(max_length=255))


    models = {
        'sponsors.category': {
            'Meta': {'object_name': 'Category'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name_en_us': ('django.db.models.fields.CharField', [], {'max_length': '120'}),
            'name_pt_br': ('django.db.models.fields.CharField', [], {'max_length': '120', 'null': 'True', 'blank': 'True'})
        },
        'sponsors.contact': {
            'Meta': {'object_name': 'Contact'},
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'sponsor': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['sponsors.Sponsor']"}),
            'type': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'sponsors.sponsor': {
            'Meta': {'object_name': 'Sponsor'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['sponsors.Category']"}),
            'description_en_us': ('django.db.models.fields.TextField', [], {'max_length': '255'}),
            'description_pt_br': ('django.db.models.fields.TextField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'logo': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'url': ('django.db.models.fields.URLField', [], {'max_length': '200'})
        }
    }

    complete_apps = ['sponsors']



from splinter.browser import Browser
# from django.conf import settings

browser = Browser()
# browser.visit('%s/admin' % settings.BASE_URL)

# browser.fill('username', 'test')
# browser.fill('password', 'test')
# browser.find_by_css('.btn-login').click()
